get_default_branch

get_default_branch(org, repo)

Arguments

org

Github organization

repo

Github repository

Value

Name of default branch on GitHub

Note

This function is not intended to be called directly, and is only exported to enable it to be used within the plumber API.

See also

Other github: get_gh_token(), get_latest_commit()