R/pkgcheck-bg.R
pkgcheck_bg.RdGenerate report on package compliance with rOpenSci Statistical Software requirements as background process
pkgcheck_bg(path)
| path | Path to local repository |
|---|
A processx object connecting to the background process generating the main pkgcheck results (see Note).
The return object will by default display whether it is still running,
or whether it has finished. Once it has finished, the results can be obtained
by calling $get_result(), or the main pkgcheck function can be
called to quickly retrieve the main results from local cache.
This function does not accept the extra_env parameter of the main
pkgcheck function, and can not be used to run extra, locally-defined
checks.
Other pkgcheck_fns:
pkgcheck()