get_default_branch
get_default_branch(org, repo)
| org | Github organization |
|---|---|
| repo | Github repository |
Name of default branch on GitHub
This function is not intended to be called directly, and is only exported to enable it to be used within the plumber API.
Other github:
get_gh_token(),
get_latest_commit()