get_latest_commit
get_latest_commit(org, repo)
| org | Github organization |
|---|---|
| repo | Github repository |
Details of latest commit including OID hash
This returns the latest commit from the default branch as specified on
GitHub, which will not necessarily be the same as information returned from
gert::git_info if the HEAD of a local repository does not point to the
same default branch.
Other github:
get_default_branch(),
get_gh_token()